@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.4.10
+-- @release v3.4.11
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -26,6 +26,13 @@ module("awful.prompt")
 local data = {}
 data.history = {}
 
+local search_term = nil
+local function itera (inc,a, i)
+	i = i + inc
+	local v = a[i]
+	if v then return i,v end
+end
+
 -- Load history file in history table
 -- @param id The data.history identifier which is the path to the filename
 -- @param max Optional parameter, the maximum number of entries in file
@@ -43,10 +50,12 @@ local function history_check_load(id, max)
 	-- Read history file
 	if f then
             for line in f:lines() do
-                table.insert(data.history[id].table, line)
-                if #data.history[id].table >= data.history[id].max then
-                   break
-		end
+                if util.table.hasitem(data.history[id].table, line) == nil then
+                        table.insert(data.history[id].table, line)
+                        if #data.history[id].table >= data.history[id].max then
+                           break
+                        end
+                end
             end
             f:close()
 	end
@@ -90,7 +99,7 @@ end
 local function history_add(id, command)
     if data.history[id] then
         if command ~= ""
-            and command ~= data.history[id].table[#data.history[id].table] then
+            and util.table.hasitem(data.history[id].table, command) == nil then
             table.insert(data.history[id].table, command)
 
             -- Do not exceed our max_cmd
@@ -164,6 +173,8 @@ function run(args, textbox, exe_callback, completion_callback, history_path, his
     local font = args.font or theme.font
     local selectall = args.selectall
 
+    search_term=nil
+
     history_check_load(history_path, history_max)
     local history_index = history_items(history_path) + 1
     -- The cursor position
@@ -222,6 +233,26 @@ function run(args, textbox, exe_callback, completion_callback, history_path, his
                 end
             elseif key == "e" then
                 cur_pos = #command + 1
+            elseif key == "r" then
+                search_term = search_term or command:sub(1, cur_pos - 1)
+                for i,v in (function(a,i) return itera(-1,a,i) end), data.history[history_path].table, history_index do
+                    if v:find(search_term) ~= nil then
+                        command=v
+                        history_index=i
+                        cur_pos=#command+1
+                        break
+                    end
+                end
+            elseif key == "s" then
+                search_term = search_term or command:sub(1, cur_pos - 1)
+                for i,v in (function(a,i) return itera(1,a,i) end), data.history[history_path].table, history_index do
+                    if v:find(search_term) ~= nil then
+                        command=v
+                        history_index=i
+                        cur_pos=#command+1
+                        break
+                    end
+                end
             elseif key == "f" then
                 if cur_pos <= #command then
                     cur_pos = cur_pos + 1
@@ -236,6 +267,24 @@ function run(args, textbox, exe_callback, completion_callback, history_path, his
             elseif key == "u" then
                 command = command:sub(cur_pos, #command)
                 cur_pos = 1
+            elseif key == "Up" then
+                search_term = search_term or command:sub(1, cur_pos - 1)
+                for i,v in (function(a,i) return itera(-1,a,i) end), data.history[history_path].table, history_index do
+                    if v:find('^'..search_term) ~= nil then
+                        command=v
+                        history_index=i
+                        break
+                    end
+                end
+            elseif key == "Down" then
+                search_term = search_term or command:sub(1, cur_pos - 1)
+                for i,v in (function(a,i) return itera(1,a,i) end), data.history[history_path].table, history_index do
+                    if v:find('^'..search_term) ~= nil then
+                        command=v
+                        history_index=i
+                        break
+                    end
+                end
             elseif key == "w" or key == "BackSpace" then
                 local wstart = 1
                 local wend = 1
