@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.4.10
+-- @release v3.4.11
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -50,10 +50,11 @@ function color_strip_alpha(color)
 end
 
 --- Make i cycle.
--- @param t A length.
+-- @param t A length. Must be greater than zero.
 -- @param i An absolute index to fit into #t.
--- @return The object at new index.
+-- @return An integer in (1, t) or nil if t is less than or equal to zero.
 function cycle(t, i)
+    if t < 1 then return end
     while i > t do i = i - t end
     while i < 1 do i = i + t end
     return i
@@ -202,6 +203,24 @@ function getdir(d)
     end
 end
 
+--- Search for an icon and return the full path.
+-- It searches for the icon path under the directories given w/the right ext
+-- @param iconname The name of the icon to search for.
+-- @param exts Table of image extensions allowed, otherwise { 'png', gif' }
+-- @param dirs Table of dirs to search, otherwise { '/usr/share/pixmaps/' }
+function geticonpath(iconname, exts, dirs)
+    exts = exts or { 'png', 'gif' }
+    dirs = dirs or { '/usr/local/share/pixmaps/' }
+    for _, d in pairs(dirs) do
+        for _, e in pairs(exts) do
+            local icon = d .. iconname .. '.' .. e
+            if file_readable(icon) then
+                return icon
+            end 
+        end 
+    end 
+end
+
 --- Check if file exists and is readable.
 -- @param filename The file path
 -- @return True if file exists and readable.
