@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008-2009 Julien Danjou
--- @release v3.4.10
+-- @release v3.4.11
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -128,7 +128,7 @@ function label.all(t, args)
         bg_color = bg_focus
         fg_color = fg_focus
     end
-    if sel then
+    if sel and sel.type ~= "desktop" then
         if taglist_squares_sel then
             -- Check that the selected clients is tagged with 't'.
             local seltags = sel:tags()
