@@ -1,7 +1,7 @@
 ----------------------------------------------------------------------------
 -- @author koniu &lt;gkusnierz@gmail.com&gt;
 -- @copyright 2008 koniu
--- @release v3.4.10
+-- @release v3.4.11
 ----------------------------------------------------------------------------
 
 -- Package environment
@@ -47,7 +47,7 @@ module("naughty")
 config = {}
 config.padding = 4
 config.spacing = 1
-config.icon_dirs = { "/usr/share/pixmaps/", }
+config.icon_dirs = { "/usr/local/share/pixmaps/", }
 config.icon_formats = { "png", "gif" }
 config.notify_callback = nil
 
@@ -139,6 +139,15 @@ function resume()
     notifications.suspended = { }
 end
 
+--- Toggle notification state
+function toggle()
+    if suspended then
+        resume()
+    else
+        suspend()
+    end
+end
+
 -- Evaluate desired position of the notification by index - internal
 -- @param idx Index of the notification
 -- @param position top_right | top_left | bottom_right | bottom_left
@@ -234,20 +243,6 @@ local function getById(id)
     end
 end
 
--- Search for an icon in specified directories with a specified format
--- @param icon Name of the icon
--- @return full path of the icon, or nil of no icon was found
-local function getIcon(name)
-    for d, dir in pairs(config.icon_dirs) do
-        for f, format in pairs(config.icon_formats) do
-            local icon = dir .. name .. "." .. format
-            if util.file_readable(icon) then
-                return icon
-            end
-        end
-    end
-end
-
 --- Create notification. args is a dictionary of (optional) arguments.
 -- @param text Text of the notification. Default: ''
 -- @param title Title of the notification. Default: nil
@@ -388,7 +383,7 @@ function notify(args)
     if icon then
         -- try to guess icon if the provided one is non-existent/readable
         if type(icon) == "string" and not util.file_readable(icon) then
-            icon = getIcon(icon)
+            icon = util.geticonpath(icon, config.icon_formats, config.icon_dirs)
         end
 
         -- if we have an icon, use it
@@ -512,13 +507,15 @@ if capi.dbus then
                 -- 1 -> width, 2 -> height, 3 -> rowstride, 4 -> has alpha
                 -- 5 -> bits per sample, 6 -> channels, 7 -> data
 
-                local imgdata
+                local imgdata = ""
                 -- If has alpha (ARGB32)
                 if hints.icon_data[6] == 4 then
-                    imgdata = hints.icon_data[7]
+                    for i = 1, #hints.icon_data[7], 4 do
+                        imgdata = imgdata .. hints.icon_data[7]:sub(i, i + 2):reverse()
+                        imgdata = imgdata .. hints.icon_data[7]:sub(i + 3, i + 3)
+                    end
                 -- If has not alpha (RGB24)
                 elseif hints.icon_data[6] == 3 then
-                    imgdata = ""
                     for i = 1, #hints.icon_data[7], 3 do
                         imgdata = imgdata .. hints.icon_data[7]:sub(i , i + 2):reverse()
                         imgdata = imgdata .. string.format("%c", 255) -- alpha is 255
